Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1432)

Unified Diff: content/browser/renderer_host/render_widget_host_impl.h

Issue 2882303002: Factor FrameData out of RendererCompositorFrameSink (Closed)
Patch Set: c Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/bad_message.h ('k') | content/browser/renderer_host/render_widget_host_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/renderer_host/render_widget_host_impl.h
diff --git a/content/browser/renderer_host/render_widget_host_impl.h b/content/browser/renderer_host/render_widget_host_impl.h
index a9807e7962c474c5e8eb5b77c0657a8327bc9d94..442b5b0a055a5f78753395063268ccc3f359e745 100644
--- a/content/browser/renderer_host/render_widget_host_impl.h
+++ b/content/browser/renderer_host/render_widget_host_impl.h
@@ -39,6 +39,7 @@
#include "content/common/drag_event_source_info.h"
#include "content/common/input/input_event_ack_state.h"
#include "content/common/input/synthetic_gesture_packet.h"
+#include "content/common/render_widget_surface_properties.h"
#include "content/common/view_message_enums.h"
#include "content/public/browser/render_widget_host.h"
#include "content/public/common/page_zoom.h"
@@ -960,11 +961,10 @@ class CONTENT_EXPORT RenderWidgetHostImpl
#endif
// These information are used to verify that the renderer does not misbehave
// when it comes to allocating LocalSurfaceIds. If frame size or device scale
// factor change, a new LocalSurfaceId must be created.
cc::LocalSurfaceId last_local_surface_id_;
- gfx::Size last_frame_size_;
- float last_device_scale_factor_;
+ RenderWidgetSurfaceProperties last_surface_properties_;
mojo::Binding<cc::mojom::MojoCompositorFrameSink>
compositor_frame_sink_binding_;
« no previous file with comments | « content/browser/bad_message.h ('k') | content/browser/renderer_host/render_widget_host_impl.cc » ('j') | no next file with comments »
@@ -960,11 +961,10 @@ class CONTENT_EXPORT RenderWidgetHostImpl
#endif
// These information are used to verify that the renderer does not misbehave
- // when it comes to allocating LocalSurfaceIds. If frame size or device scale
- // factor change, a new LocalSurfaceId must be created.
+ // when it comes to allocating LocalSurfaceIds. If surface properties change,
+ // a new LocalSurfaceId must be created.
cc::LocalSurfaceId last_local_surface_id_;

Powered by Google App Engine
This is Rietveld 408576698